@@ -37,7 +37,7 @@ func New(opts Conf) *FS {
 func (fs *FS) Save(name string, data io.Reader, _ int) error {
 	filepath := path.Join(fs.opts.Path, name)
 
-	err := os.MkdirAll(path.Dir(filepath), os.ModeDir|0775)
+	err := os.MkdirAll(path.Dir(filepath), os.ModeDir|0700)
 	if err != nil {
 		return errors.Wrapf(err, "create path %s", path.Dir(filepath))
 	}
@@ -46,13 +46,18 @@ func (fs *FS) Save(name string, data io.Reader, _ int) error {
 	if err != nil {
 		return errors.Wrapf(err, "create destination file <%s>", filepath)
 	}
-	err = os.Chmod(filepath, 0664)
+	defer fw.Close()
+	err = os.Chmod(filepath, 0600)
 	if err != nil {
 		return errors.Wrapf(err, "change permissions for file <%s>", filepath)
 	}
 
 	_, err = io.Copy(fw, data)
-	return errors.Wrap(err, "write to file")
+	if err != nil {
+		return errors.Wrapf(err, "copy file <%s>", filepath)
+	}
+
+	return errors.Wrap(fw.Sync(), "write to file")
 }
 
 func (fs *FS) SourceReader(name string) (io.ReadCloser, error) {
